@@ -1,7 +1,6 @@
-/* $Id: cpl_image_resample.c,v 1.57 2012-06-13 13:27:56 llundin Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2008 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: llundin $
- * $Date: 2012-06-13 13:27:56 $
- * $Revision: 1.57 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -428,6 +420,10 @@ cpl_error_code cpl_image_warp_polynomial(
 
   image type can be CPL_TYPE_INT, CPL_TYPE_FLOAT and CPL_TYPE_DOUBLE.
   If the image has bad pixels, they will be resampled in the same way.
+
+  The flux of the sampled pixels will be preserved, while the flux of the
+  pixels not sampled will be lost. Using steps = 2 in each direction on a
+  uniform image will thus create an image with a quarter of the flux.
   
   The returned image must be deallocated using cpl_image_delete().
 
