@@ -1,7 +1,6 @@
-/* $Id: cpl_imagelist_io.c,v 1.109 2013-04-12 07:49:36 llundin Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2008 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: llundin $
- * $Date: 2013-04-12 07:49:36 $
- * $Revision: 1.109 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -57,6 +49,9 @@
                                 Defines
  -----------------------------------------------------------------------------*/
 
+#define CPL_MSG  "Imagelist with %d image(s)\n"
+#define CPL_IMSG "Image nb %d of %d in imagelist\n"
+
 static
 cpl_imagelist * cpl_imagelist_load_one(const char *, cpl_type, cpl_size,
                                        cpl_boolean, cpl_size, cpl_size,
@@ -244,9 +239,9 @@ const cpl_image * cpl_imagelist_get_const(const cpl_imagelist * imlist,
 /**
   @ingroup cpl_imagelist
   @brief    Insert an image into an imagelist
-  @param    imlist   The imagelist
-  @param    im       The image to insert
-  @param    pos      The list position (from 0 to number of images)
+  @param    self   The imagelist
+  @param    im     The image to insert
+  @param    pos    The list position (from 0 to number of images)
   @return   CPL_ERROR_NONE or the relevant #_cpl_error_code_ on error
 
   It is allowed to specify the position equal to the number of images in the
@@ -262,67 +257,82 @@ const cpl_image * cpl_imagelist_get_const(const cpl_imagelist * imlist,
 
   It is not allowed to insert images of different size into a list.
 
-  The added image is owned by the imagelist object, which deallocates it
-  cpl_imagelist_delete is called. Other option is to use cpl_imagelist_unset to
-  recover ownership of the image, in which case the cpl_imagelist object is
+  The added image is owned by the imagelist object, which deallocates it when
+  cpl_imagelist_delete is called. Another option is to use cpl_imagelist_unset
+  to recover ownership of the image, in which case the cpl_imagelist object is
   not longer responsible for deallocating it.
 
   Possible #_cpl_error_code_ set in this function:
   - CPL_ERROR_NULL_INPUT if an input pointer is NULL
   - CPL_ERROR_ILLEGAL_INPUT if pos is negative
-  - CPL_ERROR_TYPE_MISMATCH if im and imlist are of different types
-  - CPL_ERROR_INCOMPATIBLE_INPUT if im and imlist have different sizes
+  - CPL_ERROR_TYPE_MISMATCH if im and self are of different types
+  - CPL_ERROR_INCOMPATIBLE_INPUT if im and self have different sizes
   - CPL_ERROR_ACCESS_OUT_OF_RANGE if pos is bigger than the number of
-    images in imlist
+    images in self
  */
 /*----------------------------------------------------------------------------*/
-cpl_error_code cpl_imagelist_set(
-        cpl_imagelist * imlist,
-        cpl_image     * im,
-        cpl_size        pos)
+cpl_error_code cpl_imagelist_set(cpl_imagelist * self,
+                                 cpl_image     * im,
+                                 cpl_size        pos)
 {
 
-    cpl_ensure_code(imlist,            CPL_ERROR_NULL_INPUT);
-    cpl_ensure_code(im,                CPL_ERROR_NULL_INPUT);
-    cpl_ensure_code(pos >= 0,          CPL_ERROR_ILLEGAL_INPUT);
-    cpl_ensure_code(pos <= imlist->ni, CPL_ERROR_ACCESS_OUT_OF_RANGE);
+    cpl_ensure_code(self != NULL,     CPL_ERROR_NULL_INPUT);
+    cpl_ensure_code(im   != NULL,     CPL_ERROR_NULL_INPUT);
+    cpl_ensure_code(pos  >= 0,        CPL_ERROR_ILLEGAL_INPUT);
+    cpl_ensure_code(pos  <= self->ni, CPL_ERROR_ACCESS_OUT_OF_RANGE);
 
     /* Do nothing if the image is already there */
-    if (pos < imlist->ni && im == imlist->images[pos]) return CPL_ERROR_NONE;
+    if (pos < self->ni && im == self->images[pos]) return CPL_ERROR_NONE;
 
-    if (pos > 0 || imlist->ni > 1) {
+    if (pos > 0 || self->ni > 1) {
         /* Require images to have the same size and type */
         cpl_ensure_code(cpl_image_get_size_x(im) ==
-                        cpl_image_get_size_x(imlist->images[0]),
+                        cpl_image_get_size_x(self->images[0]),
                         CPL_ERROR_INCOMPATIBLE_INPUT);
         cpl_ensure_code(cpl_image_get_size_y(im) ==
-                        cpl_image_get_size_y(imlist->images[0]),
+                        cpl_image_get_size_y(self->images[0]),
                         CPL_ERROR_INCOMPATIBLE_INPUT);
         cpl_ensure_code(cpl_image_get_type(im) ==
-                        cpl_image_get_type(imlist->images[0]),
+                        cpl_image_get_type(self->images[0]),
                         CPL_ERROR_TYPE_MISMATCH);
     }
 
-    if (pos == imlist->ni) {
-        imlist->ni++;
-        imlist->images = cpl_realloc(imlist->images,
-                                     (size_t)imlist->ni * sizeof(cpl_image*));
+    if (pos == self->ni) {
+        self->ni++;
+        self->images = cpl_realloc(self->images,
+                                     (size_t)self->ni * sizeof(cpl_image*));
     } else {
         /* Check if the image at the position to be overwritten
            is present in only one position */
         int i;
 
-        for (i = 0; i < imlist->ni; i++) {
-            if (i != pos && imlist->images[i] == imlist->images[pos]) break;
+        for (i = 0; i < self->ni; i++) {
+            if (i != pos && self->images[i] == self->images[pos]) break;
         }
-        if (i == imlist->ni) {
+        if (i == self->ni) {
             /* The image at the position to be overwritten
                is present in only one position, so delete it */
-            cpl_image_delete(imlist->images[pos]);
+
+            /* But first we must check whether its bpm is shared with others */
+            const cpl_mask * bpm = cpl_image_get_bpm_const(self->images[pos]);
+
+            if (bpm != NULL) {
+                for (i = 0; i < self->ni; i++) {
+                    if (i != pos &&
+                        bpm == cpl_image_get_bpm_const(self->images[i]))
+                        break;
+                }
+                if (i < self->ni) {
+                    /* The same bad pixel map is used also by the ith image */
+                    (void)cpl_image_unset_bpm(self->images[pos]);
+                }
+            }
+
+            cpl_image_delete(self->images[pos]);
         }
     }
 
-    imlist->images[pos] = im;
+    self->images[pos] = im;
 
     return CPL_ERROR_NONE;
 }
@@ -351,23 +361,24 @@ cpl_image * cpl_imagelist_unset(cpl_imagelist * self,
                                 cpl_size        pos)
 {
     cpl_image * out;
-    cpl_size    i;
 
-    cpl_ensure(self, CPL_ERROR_NULL_INPUT, NULL);
-    cpl_ensure(pos >= 0, CPL_ERROR_ILLEGAL_INPUT, NULL);
-    cpl_ensure(pos < self->ni, CPL_ERROR_ACCESS_OUT_OF_RANGE, NULL);
+    cpl_ensure(self != NULL,     CPL_ERROR_NULL_INPUT,          NULL);
+    cpl_ensure(pos  >= 0,        CPL_ERROR_ILLEGAL_INPUT,       NULL);
+    cpl_ensure(pos  <  self->ni, CPL_ERROR_ACCESS_OUT_OF_RANGE, NULL);
 
     /* Get pointer to image to be removed */
     out = self->images[pos];
 
-    /* Move the following images one position towards zero */
-    for (i=pos + 1; i < self->ni; i++) {
-        self->images[i-1] = self->images[i];
-    }
-
     /* Decrement of the size */
     self->ni--;
 
+    if (pos < self->ni) {
+        /* Move the following images one position towards zero */
+        (void)memmove(self->images + (size_t)pos,
+                      self->images + (size_t)pos + 1,
+                      sizeof(cpl_image*) * (size_t)(self->ni - pos));
+    }
+
     return out;
 }
 
@@ -393,13 +404,19 @@ void cpl_imagelist_empty(cpl_imagelist * self)
         while (self->ni > 0) { /* An iteration may unset more than 1 image */
             cpl_size i = self->ni - 1;
             cpl_image * del = cpl_imagelist_unset(self, i);
+            const cpl_mask * bpm = cpl_image_get_bpm_const(del);
 
             cpl_image_delete(del);
 
             /* If this image was inserted more than once into the list,
                the other insertions must be unset without a delete. */
             while (--i >= 0) {
-                if (self->images[i] == del) {
+                if (bpm != NULL &&
+                    bpm == cpl_image_get_bpm_const(self->images[i])) {
+                    /* The same bad pixel map is used also by this image */
+                    (void)cpl_image_unset_bpm(self->images[i]);
+                }
+               if (self->images[i] == del) {
                     /* This image was inserted more than once in the list */
                     (void)cpl_imagelist_unset(self, i);
                 }
@@ -446,14 +463,8 @@ void cpl_imagelist_unwrap(cpl_imagelist * self)
 /*----------------------------------------------------------------------------*/
 void cpl_imagelist_delete(cpl_imagelist * self)
 {
-
-    if (self != NULL) {
-
-        cpl_imagelist_empty(self);
-        cpl_imagelist_unwrap(self);
-    }
-
-    return;
+    cpl_imagelist_empty(self);
+    cpl_imagelist_unwrap(self);
 }
 
 /*----------------------------------------------------------------------------*/
@@ -509,7 +520,25 @@ cpl_error_code cpl_imagelist_cast(cpl_imagelist * self,
             if (cpl_imagelist_set(dest, tmpimg, m + (cpl_size)i)) break;
 
             if (inplace) {
-                cpl_image_delete(cpl_imagelist_unset(self, 0));
+                cpl_size k;
+                cpl_image* del = cpl_imagelist_unset(self, 0);
+                const cpl_mask * bpm = cpl_image_get_bpm_const(del);
+
+                /* If this image was inserted more than once into the list,
+                   it will be deleted in a subsequent iteration */
+                for (k = 0; k < self->ni; k++) {
+                    if (bpm != NULL &&
+                        bpm == cpl_image_get_bpm_const(self->images[k])) {
+                        /* The same bad pixel map is used also by this image */
+                        (void)cpl_image_unset_bpm(del);
+                    }
+                    if (self->images[k] == del) {
+                        /* This image was inserted more than once in the list */
+                        break;
+                    }
+                }
+                if (k == self->ni)
+                    cpl_image_delete(del);
             } else {
                 j++;
             }
@@ -610,7 +639,26 @@ cpl_error_code cpl_imagelist_erase(
             nkeep++;
         } else {
             /* image is to be erased, delete it */
-            cpl_image_delete(imlist->images[i]);
+            cpl_size k;
+            const cpl_mask * bpm = cpl_image_get_bpm_const(imlist->images[i]);
+
+            /* If this image was inserted more than once into the list,
+               it will be deleted in a subsequent iteration */
+            for (k = 0; k < imlist->ni; k++) {
+                if (k < nkeep || i < k) {
+                    if (bpm != NULL &&
+                        bpm == cpl_image_get_bpm_const(imlist->images[k])) {
+                        /* The same bad pixel map is used also by this image */
+                        (void)cpl_image_unset_bpm(imlist->images[i]);
+                    }
+                    if (imlist->images[k] == imlist->images[i]) {
+                        /* This image was inserted more than once in the list */
+                        break;
+                    }
+                }
+            }
+            if (k == imlist->ni)
+                cpl_image_delete(imlist->images[i]);
         }
     }
 
@@ -742,23 +790,21 @@ int cpl_imagelist_is_uniform(const cpl_imagelist * imlist)
 cpl_error_code cpl_imagelist_dump_structure(const cpl_imagelist * self,
                         FILE * stream)
 {
-    const char * msg    = "Imagelist with %d image(s)\n";
-    const int    msgmin = (int)strlen(msg) - 5;
+    const int    msgmin = (int)strlen(CPL_MSG) - 5;
 
     int i;
 
     cpl_ensure_code(self   != NULL, CPL_ERROR_NULL_INPUT);
     cpl_ensure_code(stream != NULL, CPL_ERROR_NULL_INPUT);
 
-    cpl_ensure_code( fprintf(stream,  msg, self->ni) >= msgmin,
+    cpl_ensure_code( fprintf(stream,  CPL_MSG, (int)self->ni) >= msgmin,
              CPL_ERROR_FILE_IO );
 
     for (i = 0; i < self -> ni; i++) {
     const cpl_image * image   = cpl_imagelist_get_const(self, i);
-    const char      * imsg    = "Image nb %d of %d in imagelist\n";
-    const int         imsgmin = (int)strlen(imsg) - 5;
+    const int         imsgmin = (int)strlen(CPL_IMSG) - 5;
 
-    cpl_ensure_code( fprintf(stream,  imsg, i, self->ni) >= imsgmin,
+    cpl_ensure_code( fprintf(stream,  CPL_IMSG, i, (int)self->ni) >= imsgmin,
              CPL_ERROR_FILE_IO );
 
     cpl_ensure_code( !cpl_image_dump_structure(image, stream),
@@ -799,11 +845,10 @@ cpl_error_code cpl_imagelist_dump_window(const cpl_imagelist * self,
 
     for (i = 0; i < self -> ni; i++) {
     const cpl_image * image   = cpl_imagelist_get_const(self, i);
-    const char      * imsg    = "Image nb %d of %d in imagelist\n";
-    const int         imsgmin = (int)strlen(imsg) - 5;
+    const int         imsgmin = (int)strlen(CPL_IMSG) - 5;
 
-    cpl_ensure_code( fprintf(stream,  imsg, i, self->ni) >= imsgmin,
-             CPL_ERROR_FILE_IO );
+    cpl_ensure_code( fprintf(stream,  CPL_IMSG, (int)i,
+                             (int)self->ni) >= imsgmin, CPL_ERROR_FILE_IO );
 
     cpl_ensure_code( !cpl_image_dump_window(image, llx, lly, urx, ury,
                            stream),
