@@ -1,7 +1,6 @@
-/* $Id: cpl_io_fits.h,v 1.15 2012-05-11 13:26:27 llundin Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2008 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: llundin $
- * $Date: 2012-05-11 13:26:27 $
- * $Revision: 1.15 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifndef CPL_IO_FITS_H
 #define CPL_IO_FITS_H
 
@@ -65,19 +57,28 @@ CPL_BEGIN_DECLS
 #define CPL_HAVE_STAT
 #endif
 
-#ifdef CPL_HAVE_STAT
-#  if !defined CPL_IO_FITS_MAX_OPEN || CPL_IO_FITS_MAX_OPEN > NMAXFILES
-#    undef CPL_IO_FITS_MAX_OPEN
-/*   May be defined to zero to disable the caching of file handles */
-/*   Default value is the maximum allowed by CFITSIO, but can be defined
-     (to less) if needed due to a limit imposed by e.g. setrlimit()
-*/
-#    define CPL_IO_FITS_MAX_OPEN NMAXFILES
-#  endif
-#else
+#undef CPL_IO_FITS
+#ifndef CPL_HAVE_STAT
 /* Without stat() the caching is disabled */
+#elif defined CPL_IO_FITS_MAX_OPEN && CPL_IO_FITS_MAX_OPEN  == 0
+/* May be defined to zero to disable the caching of file handles */
+#else
+#  define CPL_IO_FITS
+#endif
+
+#ifndef CPL_IO_FITS
 #  undef CPL_IO_FITS_MAX_OPEN
 #  define CPL_IO_FITS_MAX_OPEN 0
+#elif !defined CPL_IO_FITS_MAX_OPEN || CPL_IO_FITS_MAX_OPEN > NMAXFILES
+#  undef CPL_IO_FITS_MAX_OPEN
+/* May be defined to zero to disable the caching of file handles */
+/* Default value is the maximum allowed by CFITSIO, but can be defined
+   (to less) if needed due to a limit imposed by e.g. setrlimit()
+*/
+#  define CPL_IO_FITS_MAX_OPEN NMAXFILES
+#elif CPL_IO_FITS_MAX_OPEN < 0
+/* Prevent trouble from a manually set value */
+#  error "CPL_IO_FITS_MAX_OPEN has am illegal, negative value"
 #endif
 
 #define CPL_IO_FITS_ALL CPL_TRUE
@@ -103,6 +104,13 @@ int cpl_io_fits_close_file(fitsfile *, int *)
 #endif
     ;
 
+int cpl_io_fits_delete_file(fitsfile *, int *)
+    CPL_INTERNAL
+#ifdef CPL_HAVE_ATTR_NONNULL
+    __attribute__((nonnull(2)))
+#endif
+    ;
+
 cpl_error_code cpl_io_fits_close_tid(cpl_boolean);
 
 int cpl_io_fits_close(const char *, int *)
