@@ -1,7 +1,6 @@
-/* $Id: cpl_polynomial.h,v 1.40 2011-12-14 12:29:06 llundin Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2008 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: llundin $
- * $Date: 2011-12-14 12:29:06 $
- * $Revision: 1.40 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifndef CPL_POLYNOMIAL_H
 #define CPL_POLYNOMIAL_H
 
@@ -32,11 +24,11 @@
                                    Includes
  -----------------------------------------------------------------------------*/
 
-#include <stdio.h>
 #include <cpl_macros.h>
-#include "cpl_vector.h"
-#include "cpl_bivector.h"
-#include "cpl_error.h"
+#include <cpl_vector.h>
+#include <cpl_bivector.h>
+#include <cpl_error.h>
+#include <stdio.h>
 
 CPL_BEGIN_DECLS
 
