@@ -1,7 +1,6 @@
-/* $Id: cpl_stats_impl.h,v 1.4 2011-07-19 11:05:43 llundin Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2005 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: llundin $
- * $Date: 2011-07-19 11:05:43 $
- * $Revision: 1.4 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifndef CPL_STATS_IMPL_H
 #define CPL_STATS_IMPL_H
 
@@ -42,5 +34,7 @@ cpl_error_code cpl_stats_fill_from_image_window(cpl_stats *, const cpl_image *,
     CPL_INTERNAL
 ;
 
+CPL_END_DECLS
+
 #endif
 /* end of cpl_stats_impl.h */
