@@ -1,7 +1,6 @@
-/* $Id: cpl_test.h,v 1.63 2013-04-04 13:10:32 llundin Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2008 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: llundin $
- * $Date: 2013-04-04 13:10:32 $
- * $Revision: 1.63 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifndef CPL_TEST_H
 #define CPL_TEST_H
 
@@ -1002,7 +994,7 @@ typedef unsigned long long int cpl_flops;
  -----------------------------------------------------------------------------*/
 
 void cpl_test_init_macro(const char *, const char *,
-                         cpl_msg_severity) CPL_ATTR_NONNULL;
+                         cpl_msg_severity);
 int cpl_test_end(cpl_size);
 void cpl_test_macro(int, double, cpl_flops, cpl_errorstate, cpl_size,
                     cpl_boolean, const char *, const char *,
