@@ -1,7 +1,6 @@
-/* $Id: cpl_tools.c,v 1.124 2012-02-27 16:12:47 rpalsa Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2008 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: rpalsa $
- * $Date: 2012-02-27 16:12:47 $
- * $Revision: 1.124 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -175,6 +167,7 @@ static cpl_flops flop_count = 0;
                             Function codes
  -----------------------------------------------------------------------------*/
 
+#define CPL_TYPE_IS_TYPE_PIXEL
 #define CPL_TYPE_IS_NUM
 #define CPL_TYPE int
 #define CPL_TYPE_NAME int
@@ -183,6 +176,7 @@ static cpl_flops flop_count = 0;
 #undef CPL_TYPE
 #undef CPL_TYPE_NAME
 #undef CPL_TOOLS_SORT_LT
+#undef CPL_TYPE_IS_TYPE_PIXEL
 
 #define CPL_TYPE_IS_NUM
 #define CPL_TYPE long
@@ -210,6 +204,7 @@ static cpl_flops flop_count = 0;
 #undef CPL_TYPE_NAME
 #undef CPL_TOOLS_SORT_LT
 
+#define CPL_TYPE_IS_TYPE_PIXEL
 #define CPL_TYPE float
 #define CPL_TYPE_NAME float
 #define CPL_TOOLS_SORT_LT(x,y) ((x) < (y))
@@ -226,6 +221,7 @@ static cpl_flops flop_count = 0;
 #undef CPL_TYPE_NAME
 #undef CPL_TOOLS_SORT_LT
 #undef CPL_TYPE_IS_NUM
+#undef CPL_TYPE_IS_TYPE_PIXEL
 
 #define CPL_TYPE char *
 #define CPL_TYPE_NAME string
@@ -579,17 +575,17 @@ static cpl_fits_keytype cpl_fits_property_get_type(const char * key)
   @brief    Add to the FLOPS counter.
   @param flops  FLOPS to add
   @return   void
-  @note This function is intended to be used only by the CPL test modules.
+  @note If compiled with -DCPL_ADD_FLOPS this function will incur significant
+        thread scheduling and CPU overhead, if not it will not be used.
 
  */
 /*----------------------------------------------------------------------------*/
-inline void cpl_tools_add_flops(cpl_flops flops)
+inline void cpl_tools_add_flops_(cpl_flops flops)
 {
 #ifdef _OPENMP
 #pragma omp atomic
 #endif
     flop_count += flops;
-
 }
 
 /*----------------------------------------------------------------------------*/
@@ -598,6 +594,7 @@ inline void cpl_tools_add_flops(cpl_flops flops)
   @brief    Get the FLOPS count.
   @return   The FLOPS count
   @note This function is intended to be used only by the CPL test modules.
+  @note If compiled with -DCPL_ADD_FLOPS this function will always return zero.
 
  */
 /*----------------------------------------------------------------------------*/
@@ -613,7 +610,7 @@ cpl_flops cpl_tools_get_flops(void)
   @param    x   The vector to be transformed
   @param    pm  On return, *pm is the mean of x
   @return   The created transformed vector
-  @note     The function will cx_assert() on NULL input.
+  @note No NULL-pointer check in this internal function
 
  */
 /*----------------------------------------------------------------------------*/
@@ -622,10 +619,6 @@ cpl_vector * cpl_vector_transform_mean(const cpl_vector * x, double * pm)
 
     cpl_vector * xhat = cpl_vector_duplicate(x);
 
-
-    cx_assert( xhat != NULL );
-    cx_assert( pm   != NULL );
-
     *pm = cpl_vector_get_mean(xhat);
     cpl_vector_subtract_scalar(xhat, *pm);
 
@@ -727,6 +720,7 @@ cpl_error_code cpl_vector_ensure_distinct(const cpl_vector * self,
 
 /*----------------------------------------------------------------------------*/
 /**
+  @internal
   @brief    Copy a rectangular memory area from one place to another
   @param    self        Preallocated location to copy to
   @param    src         Location to copy from
@@ -739,10 +733,10 @@ cpl_error_code cpl_vector_ensure_distinct(const cpl_vector * self,
   @param    ury         Upper right y position
   @return  CPL_ERROR_NONE if OK, otherwise the relevant #_cpl_error_code_.
   @note self must have place for (urx-llx+1) * (ury-lly+1) elements of size size
+  @note No NULL-pointer check in this internal function
   @see mempcy()
 
   Possible #_cpl_error_code_ set in this function:
-  - CPL_ERROR_NULL_INPUT if an input pointer is NULL
   - CPL_ERROR_ILLEGAL_INPUT if the window coordinates are not valid
  */
 /*----------------------------------------------------------------------------*/
@@ -755,8 +749,6 @@ cpl_error_code cpl_tools_copy_window(void *self, const void *src, size_t size,
     /* FIXME: Need to do pointer arithmetic */
     const char * csrc  = (const char*)src;
 
-    cpl_ensure_code(self,       CPL_ERROR_NULL_INPUT);
-    cpl_ensure_code(src,        CPL_ERROR_NULL_INPUT);
     cpl_ensure_code(size != 0,  CPL_ERROR_ILLEGAL_INPUT);
 
     cpl_ensure_code(llx <= urx, CPL_ERROR_ILLEGAL_INPUT);
@@ -800,6 +792,7 @@ cpl_error_code cpl_tools_copy_window(void *self, const void *src, size_t size,
 
 /*----------------------------------------------------------------------------*/
 /**
+  @internal
   @brief    Shift a rectangular memory area
   @param    self    Location of 1st element
   @param    size    Size of each element [bytes]
@@ -809,6 +802,7 @@ cpl_error_code cpl_tools_copy_window(void *self, const void *src, size_t size,
   @param    dx      Shift in X
   @param    dy      Shift in Y
   @return   the #_cpl_error_code_ or CPL_ERROR_NONE
+  @note No NULL-pointer check in this internal function
   @see cpl_mask_shift()
 
   The 'empty zone' in the shifted rectangle is filled with size null's.
@@ -836,7 +830,6 @@ cpl_error_code cpl_tools_shift_window(void * self, size_t size,
     char * psrc  = dy > 0 ? myself : myself + sset; /* const */
     char * pset  = dy > 0 ? myself : myself + smove;
 
-    cpl_ensure_code(self != NULL, CPL_ERROR_NULL_INPUT);
     cpl_ensure_code(size >  0,    CPL_ERROR_ILLEGAL_INPUT);
     cpl_ensure_code(nx   >  0,    CPL_ERROR_ILLEGAL_INPUT);
     cpl_ensure_code(ny   >  0,    CPL_ERROR_ILLEGAL_INPUT);
