@@ -1,7 +1,6 @@
-/* $Id: cpl_tools.h,v 1.111 2012-02-27 16:12:47 rpalsa Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2008 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: rpalsa $
- * $Date: 2012-02-27 16:12:47 $
- * $Revision: 1.111 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifndef CPL_TOOLS_H
 #define CPL_TOOLS_H
 
@@ -55,6 +47,8 @@
 #include "cpl_type.h"
 #include "cpl_type_impl.h"
 
+CPL_BEGIN_DECLS
+
 /*-----------------------------------------------------------------------------
                                    Define
  -----------------------------------------------------------------------------*/
@@ -84,6 +78,38 @@
         "|ZTILE[0-9]|ZBITPIX|ZNAXIS[0-9]|ZSCALE|ZZERO"    \
         "|ZBLANK|ZHECKSUM|ZDATASUM" ")$"
 
+/**
+   @internal
+   @brief CFITSIO wrapper without warning for const violation
+   @see fits_get_colnum
+   @note Missing one const modifier in CFITSIO 3.42
+*/
+#define cpl_fits_get_colnum(A, B, C, D, E)      \
+    CPL_DIAG_PRAGMA_PUSH_IGN(-Wcast-qual);      \
+    fits_get_colnum(A, B, (char*)C, D, E);      \
+    CPL_DIAG_PRAGMA_POP
+
+/**
+   @internal
+   @brief CFITSIO wrapper without warning for const violation
+   @see fits_write_colnull
+   @note Missing two const modifiers in CFITSIO 3.42
+*/
+#define cpl_fits_write_colnull(A, B, C, D, E, F, G, H, I)               \
+    CPL_DIAG_PRAGMA_PUSH_IGN(-Wcast-qual);                              \
+    fits_write_colnull(A, B, C, D, E, F, (void*)G, (void*)H, I);        \
+    CPL_DIAG_PRAGMA_POP
+
+/**
+   @internal
+   @brief CFITSIO wrapper without warning for const violation
+   @see fits_create_tbl
+   @note Missing three const modifiers in CFITSIO 3.42
+*/
+#define cpl_fits_create_tbl(A, B, C, D, E, F, G, H, I)                  \
+    CPL_DIAG_PRAGMA_PUSH_IGN(-Wcast-qual);                              \
+    fits_create_tbl(A, B, C, D, (char**)E, (char**)F, (char**)G, H, I); \
+    CPL_DIAG_PRAGMA_POP
 
 /* CFITSIO support for I/O of largest possible buffers. */
 /* FIXME: Add CPL_FITSIO_FORMAT w. "ld" for long int, but
@@ -110,6 +136,13 @@
 #define CPL_FITSIO_TYPE long int
 #endif
 
+#ifdef CPL_ADD_FLOPS
+#define cpl_tools_add_flops cpl_tools_add_flops_
+#else
+#define cpl_tools_add_flops(A) /* Do nothing */
+#endif
+
+
 /*----------------------------------------------------------------------------*/
 /**
    @internal
@@ -301,10 +334,22 @@ void cpl_tools_sort_desc_long(long *, int) CPL_ATTR_NONNULL;
 void cpl_tools_sort_desc_long_long(long long *, int) CPL_ATTR_NONNULL;
 void cpl_tools_sort_desc_cplsize(cpl_size *, int) CPL_ATTR_NONNULL;
 
-cpl_vector * cpl_vector_transform_mean(const cpl_vector *, double *) CPL_ATTR_NONNULL;
+void cpl_tools_flip_double(double *, size_t) CPL_ATTR_NONNULL CPL_INTERNAL;
+void cpl_tools_flip_float(float *, size_t) CPL_ATTR_NONNULL CPL_INTERNAL;
+void cpl_tools_flip_int(int *, size_t) CPL_ATTR_NONNULL CPL_INTERNAL;
 
-void cpl_tools_add_flops(cpl_flops);
-cpl_flops cpl_tools_get_flops(void) CPL_ATTR_PURE;
+cpl_vector * cpl_vector_transform_mean(const cpl_vector *, double *)
+    CPL_ATTR_NONNULL CPL_ATTR_ALLOC;
+
+void cpl_tools_add_flops_(cpl_flops);
+
+cpl_flops cpl_tools_get_flops(void)
+#ifdef CPL_ADD_FLOPS
+     CPL_ATTR_PURE
+#else
+     CPL_ATTR_CONST
+#endif
+     ;
 
 /* Others */
 cpl_size cpl_tools_is_power_of_2(cpl_size) CPL_ATTR_CONST;
@@ -318,4 +363,7 @@ int cpl_tools_get_bpp(cpl_type);
 cpl_error_code cpl_vector_count_distinct(cpl_vector *, cpl_size *);
 cpl_error_code cpl_vector_ensure_distinct(const cpl_vector *, cpl_size);
 
+CPL_END_DECLS
+
 #endif 
+
