@@ -1,7 +1,6 @@
-/* $Id: cpl_tools_body.h,v 1.33 2013-05-28 08:33:57 llundin Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2008 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: llundin $
- * $Date: 2013-05-28 08:33:57 $
- * $Revision: 1.33 $
- * $Name: not supported by cvs2svn $
- */
-
 #undef ADDTYPE
 #define ADDTYPE(a) CONCAT2X(a, CPL_TYPE_NAME)
 
@@ -87,6 +79,26 @@ static void ADDTYPE(cpl_tools_get_0th)(CPL_TYPE * self, size_t n)
     CPL_TYPE_SWAP(self[0], self[amin]);
 }
 
+#ifdef CPL_TYPE_IS_TYPE_PIXEL
+
+/*----------------------------------------------------------------------------*/
+/**
+  @internal
+  @brief  Flip (reverse the order of) the elements of the array
+  @param  self The array to flip in place
+  @param  n    The array size, nop unless greater than 1
+  @return void
+  @note Since the function is not exported its error checking is disabled
+
+ */
+/*----------------------------------------------------------------------------*/
+void ADDTYPE(cpl_tools_flip)(CPL_TYPE * self, size_t n)
+{
+    for (size_t i = 0; i < n/2; i++) {
+        CPL_TYPE_SWAP(self[i], self[n-1-i]);
+    }
+}
+#endif
 /*----------------------------------------------------------------------------*/
 /**
   @internal
@@ -632,13 +644,15 @@ static int ADDTYPE(compar_desc)(const void * p1, const void * p2)
   @note Since the function is not exported its error checking is disabled
   @note Benchmarking up to 10M randomized elements on a Xeon E5345 show no
         significant advantage over cpl_tools_get_kth. However, for an almost
-        sorted array, quick select can be a lot faster.
+        sorted array, Quickselect can be a lot faster.
 
-    This Quickselect routine is based on the algorithm described in
-    "Numerical recipes in C", Second Edition,
-    Cambridge University Press, 1992, Section 8.5, ISBN 0-521-43108-5
-   
-  See also: http://ndevilla.free.fr/median/median/
+    The Quickselect algorithm is derived from the Quicksort algorithm, see e.g.
+
+    https://en.wikipedia.org/wiki/Quickselect
+
+    Comments on the below implementation and its performance can be found at
+  
+    http://ndevilla.free.fr/median/median/
 
  */
 /*----------------------------------------------------------------------------*/
