@@ -1,7 +1,6 @@
-/* $Id: cpl_vector_impl.h,v 1.1 2011-12-07 14:20:48 llundin Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2005 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: llundin $
- * $Date: 2011-12-07 14:20:48 $
- * $Revision: 1.1 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifndef CPL_VECTOR_IMPL_H
 #define CPL_VECTOR_IMPL_H
 
@@ -32,7 +24,7 @@
 
 CPL_BEGIN_DECLS
 
-void * cpl_vector_rewrap(cpl_vector * self, cpl_size, double *);
+double * cpl_vector_rewrap(cpl_vector *, cpl_size, double *);
 
 #endif
 /* end of cpl_vector_impl.h */
