@@ -1,7 +1,6 @@
-/* $Id: cpl_xmemory.c,v 1.43 2012-11-15 10:25:16 llundin Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2008 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: llundin $
- * $Date: 2012-11-15 10:25:16 $
- * $Revision: 1.43 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -282,10 +274,13 @@ void * cpl_xmemory_realloc_count(void * oldptr, size_t size)
 
         ptr = cpl_xmemory_malloc_count(size);
 
+#ifndef _OPENMP
+        /* Need to disable this non-threadsafe check with thread-support */
     } else if (cpl_xmemory_ncells == 0) {
         fprintf(stderr, "cpl_xmemory error: Ignoring realloc() to %zu bytes on "
                 "unallocated pointer (%p)\n", size, oldptr);
         ptr = NULL;
+#endif
     } else {
 
         /* assert( oldptr != NULL ); */
@@ -329,18 +324,21 @@ void cpl_xmemory_free_count(void * ptr)
 {
 
     if (ptr != NULL) {
+#ifndef _OPENMP
+        /* Need to disable this non-threadsafe check with thread-support */
         if (cpl_xmemory_ncells == 0) {
             fprintf(stderr, "cpl_xmemory error: Ignoring free() on "
                     "unallocated pointer (%p)\n", ptr);
-        } else {
-            free(ptr);
-
-#           ifdef _OPENMP
-#           pragma omp atomic
-#           endif
-            cpl_xmemory_ncells--;
-
+            return;
         }
+#endif
+        free(ptr);
+
+#       ifdef _OPENMP
+#       pragma omp atomic
+#       endif
+        cpl_xmemory_ncells--;
+
     }
 
     return;
