@@ -1,7 +1,6 @@
-/* $Id: cpl_fits-test.c,v 1.22 2012-05-11 13:21:03 llundin Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2008 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: llundin $
- * $Date: 2012-05-11 13:21:03 $
- * $Revision: 1.22 $
- * $Name: not supported by cvs2svn $
- */
-
 /*-----------------------------------------------------------------------------
                                    Includes
  -----------------------------------------------------------------------------*/
@@ -170,7 +162,7 @@ static void cpl_fits_mode_test(void)
     cpl_error_code code;
     cpl_fits_mode mode, modec;
 
-#if CPL_IO_FITS_MAX_OPEN > 0
+#ifdef CPL_IO_FITS
     cpl_fits_mode modeo;
 
     /* Copied from cpl_init() */
@@ -196,7 +188,7 @@ static void cpl_fits_mode_test(void)
     cpl_test_error(CPL_ERROR_NONE);
     cpl_test_eq(mode, modec);
 
-#if CPL_IO_FITS_MAX_OPEN > 0
+#ifdef CPL_IO_FITS
     /* Change to the other mode */
     modeo = use_io_fits ? CPL_FITS_STOP_CACHING : CPL_FITS_START_CACHING;
     code = cpl_fits_set_mode(modeo);
