@@ -1,7 +1,6 @@
-/* $Id: cpl_imagelist_io-test.c,v 1.61 2013-04-26 08:24:00 llundin Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2008 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: llundin $
- * $Date: 2013-04-26 08:24:00 $
- * $Revision: 1.61 $
- * $Name: not supported by cvs2svn $
- */
-
 /*-----------------------------------------------------------------------------
                                    Includes
  -----------------------------------------------------------------------------*/
@@ -269,15 +261,21 @@ int main(void)
     cpl_test_zero( cpl_imagelist_is_uniform(imlist2));
     cpl_test_eq( cpl_imagelist_get_size(imlist2), 2 * NIMAGES );
 
+    /* Test a cast with a shared image */
+    error = cpl_imagelist_set(imlist2, cpl_imagelist_get(imlist2, 0),
+                              cpl_imagelist_get_size(imlist2));
+    cpl_test_eq( cpl_imagelist_get_size(imlist2), 2 * NIMAGES + 1);
+
+    cpl_test_eq_error(error, CPL_ERROR_NONE);
     error = cpl_imagelist_cast(imlist2, NULL, CPL_TYPE_FLOAT_COMPLEX);
     cpl_test_eq_error(error, CPL_ERROR_NONE);
     cpl_test_zero( cpl_imagelist_is_uniform(imlist2));
-    cpl_test_eq( cpl_imagelist_get_size(imlist2), 2 * NIMAGES );
+    cpl_test_eq( cpl_imagelist_get_size(imlist2), 2 * NIMAGES + 1);
 
     error = cpl_imagelist_cast(imlist2, NULL, CPL_TYPE_FLOAT);
     cpl_test_eq_error(error, CPL_ERROR_TYPE_MISMATCH);
     cpl_test_zero( cpl_imagelist_is_uniform(imlist2));
-    cpl_test_eq( cpl_imagelist_get_size(imlist2), 2 * NIMAGES );
+    cpl_test_eq( cpl_imagelist_get_size(imlist2), 2 * NIMAGES + 1);
 
     cpl_imagelist_delete(imlist2);
 
@@ -462,6 +460,9 @@ int main(void)
     cpl_test_zero( cpl_imagelist_is_uniform(imlist) );
     cpl_test_eq( cpl_imagelist_get_size(imlist), NIMAGES );
 
+    error = cpl_imagelist_set(imlist, cpl_imagelist_get(imlist, 0), 2);
+    cpl_test_eq_error(error, CPL_ERROR_NONE);
+
     error = cpl_imagelist_erase(imlist, eraser);
     cpl_test_eq_error(error, CPL_ERROR_NONE);
     cpl_test_zero( cpl_imagelist_is_uniform(imlist) );
