@@ -1,7 +1,6 @@
-/* $Id: cpl_memory-test.c,v 1.27 2011-12-21 13:15:31 llundin Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2008 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: llundin $
- * $Date: 2011-12-21 13:15:31 $
- * $Revision: 1.27 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -279,6 +271,7 @@ int main(void)
         cpl_test_error(CPL_ERROR_NONE);
 
         cpl_test_nonnull(nonnull);
+        cpl_test_noneq_string(nonnull, "");
 
         cpl_free(nonnull);
 
