@@ -1,7 +1,6 @@
-/* $Id: cpl_vector-test.c,v 1.99 2013-04-29 07:55:53 llundin Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2008 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,26 +17,20 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: llundin $
- * $Date: 2013-04-29 07:55:53 $
- * $Revision: 1.99 $
- * $Name: not supported by cvs2svn $
- */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 /*-----------------------------------------------------------------------------
                                    Includes
  -----------------------------------------------------------------------------*/
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "cpl_io_fits.h"
 #include "cpl_test.h"
 #include "cpl_tools.h"
 #include "cpl_math_const.h"
 #include "cpl_memory.h"
+#include "cpl_plot.h"
 
 #include <float.h>
 #include <assert.h>
@@ -55,10 +48,13 @@
                         Private function prototypes
  -----------------------------------------------------------------------------*/
 
+static void cpl_vector_cycle_test(cpl_size);
 static void cpl_vector_save_bench(int);
 static void cpl_vector_get_stdev_bench(int);
 static void cpl_vector_corr_bench(int);
 static void cpl_vector_fit_gaussian_test_one(FILE *);
+static void cpl_vector_valarray_bench_one(cpl_vector *, cpl_vector *);
+static void cpl_vector_valarray_bench(cpl_size);
 /*-----------------------------------------------------------------------------
                                   Main
  -----------------------------------------------------------------------------*/
@@ -110,6 +106,12 @@ int main(void)
 
     cpl_test_nonnull( stream );
 
+    /* Test both odd and even numbered */
+    cpl_vector_cycle_test(13);
+    cpl_vector_cycle_test(16);
+    cpl_vector_cycle_test(VECTOR_SIZE);
+    cpl_vector_cycle_test(VECTOR_SIZE + 1);
+
     cpl_vector_fit_gaussian_test_one(stream);
 
     null = cpl_vector_new(0);
@@ -159,8 +161,10 @@ int main(void)
         cpl_vector_set(taylor, i, cpl_vector_get(taylor, i-1)/i);
 
     /* Evaluate exp(sinus) using Horners scheme on the Taylor expansion */
-    cpl_test( tmp_vec2 = cpl_vector_new(VECTOR_SIZE) );
-    cpl_test_zero( cpl_vector_fill(tmp_vec2, cpl_vector_get(taylor, POLY_SIZE-1)) );
+    tmp_vec2 = cpl_vector_new(VECTOR_SIZE);
+    cpl_test_nonnull(tmp_vec2);
+    error = cpl_vector_fill(tmp_vec2, cpl_vector_get(taylor, POLY_SIZE-1));
+    cpl_test_eq_error(error, CPL_ERROR_NONE);
     
     for (k=POLY_SIZE-1; k > 0; k--) {
         cpl_test_zero( cpl_vector_multiply(tmp_vec2, sinus) );
@@ -203,6 +207,14 @@ int main(void)
     /* Much less precise than Horner ... */
     cpl_test_vector_abs(tmp_vec, tmp_vec2, 8.0 * DBL_EPSILON);
 
+    /* cpl_vector_fill(): Test with NULL and zero value */
+    error = cpl_vector_fill(NULL, 0.0);
+    cpl_test_eq_error(error, CPL_ERROR_NULL_INPUT);
+    error = cpl_vector_fill(taylor, 0.0);
+    cpl_test_eq_error(error, CPL_ERROR_NONE);
+    cpl_test_abs(cpl_vector_get_max(taylor), 0.0, 0.0);
+    cpl_test_abs(cpl_vector_get_min(taylor), 0.0, 0.0);
+
     cpl_vector_delete(taylor);
 
     /* Verify cpl_vector_logarithm() ) */
@@ -459,13 +471,18 @@ int main(void)
     cpl_test_error(CPL_ERROR_ACCESS_OUT_OF_RANGE);
     cpl_test_null( null );
 
+    CPL_DIAG_PRAGMA_PUSH_IGN(-Wcast-qual);
     vxc = cpl_vector_wrap(5, (double*)five);
+    CPL_DIAG_PRAGMA_POP;
+
     vxc1 = cpl_vector_extract(vxc, 1, 4, 1);
     cpl_test_error(CPL_ERROR_NONE);
 
     cpl_test_eq_ptr(five, cpl_vector_unwrap(vxc));
 
+    CPL_DIAG_PRAGMA_PUSH_IGN(-Wcast-qual);
     vxc = cpl_vector_wrap(4, (double*)five + 1);
+    CPL_DIAG_PRAGMA_POP;
     cpl_test_vector_abs(vxc, vxc1, 0.0);
 
     (void)cpl_vector_unwrap(vxc);
@@ -527,9 +544,30 @@ int main(void)
     cpl_vector_delete(tmp_vec);
 
     tmp_vec = cpl_vector_filter_median_create(sinus, 2);
-    cpl_test_eq( cpl_vector_get_size(tmp_vec), cpl_vector_get_size(sinus) );
+    cpl_test_error(CPL_ERROR_NONE);
+    cpl_test_eq( cpl_vector_get_size(tmp_vec), VECTOR_SIZE );
     cpl_vector_delete(tmp_vec);
 
+    tmp_vec = cpl_vector_filter_median_create(sinus, VECTOR_SIZE/2);
+    cpl_test_error(CPL_ERROR_NONE);
+    cpl_test_eq( cpl_vector_get_size(tmp_vec), VECTOR_SIZE );
+    if (2 * (VECTOR_SIZE/2) == cpl_vector_get_size(tmp_vec))
+        cpl_test_vector_abs(tmp_vec, sinus, 0.0);
+
+    cpl_vector_delete(tmp_vec);
+
+    null = cpl_vector_filter_median_create(sinus, -1);
+    cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
+    cpl_test_null(null);
+
+    null = cpl_vector_filter_median_create(sinus, 1 + VECTOR_SIZE/2);
+    cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
+    cpl_test_null(null);
+
+    null = cpl_vector_filter_median_create(NULL, 0);
+    cpl_test_error(CPL_ERROR_NULL_INPUT);
+    cpl_test_null(null);
+
     /* Test existence of cpl_vector_fit_gaussian() */
     error = cpl_vector_fit_gaussian(NULL, NULL, NULL, NULL, CPL_FIT_ALL,
                                     NULL, NULL, NULL, NULL, NULL, NULL, NULL);
@@ -702,14 +740,14 @@ int main(void)
             delta = cpl_vector_correlate(vxc, sinus, cosinus);
             xc = cpl_vector_get(vxc, delta);
             cpl_test( xc > xcp );
-            cpl_test_eq( abs(delta-(i+1)), i+1 );
+            cpl_test_eq( llabs(delta-(i+1)), i+1 );
         }
         cpl_test_abs( xc, 1.0, 260*DBL_EPSILON);
         half_search = VECTOR_SIZE/3;
         cpl_test_zero( cpl_vector_set_size(vxc, 2*half_search + 1) );
         delta = cpl_vector_correlate(vxc, sinus, cosinus);
         xc = cpl_vector_get(vxc, delta );
-        cpl_test_eq( abs(delta-VECTOR_SIZE/3), VECTOR_SIZE/4 );
+        cpl_test_eq( llabs(delta-VECTOR_SIZE/3), VECTOR_SIZE/4 );
         if (fabs(1-xc) > emax) emax = fabs(1-xc);
     }
 
@@ -897,6 +935,20 @@ int main(void)
         cpl_vector_save_bench(1);
     }
 
+    if (do_bench) {
+        cpl_vector_valarray_bench(10);
+        cpl_vector_valarray_bench(50000);
+        cpl_vector_valarray_bench(500000);
+        cpl_vector_valarray_bench(5000000);
+    } else {
+        cpl_vector_valarray_bench(10);
+    }
+
+    if (getenv("CPL_VALARRAY_SIZE")) {
+        const int nvalarray = atoi(getenv("CPL_VALARRAY_SIZE"));
+        cpl_vector_valarray_bench(nvalarray);
+    }
+
     /* Free and return */
     cpl_vector_delete(cosinus);
     cpl_vector_delete(sinus);
@@ -1025,12 +1077,17 @@ static void cpl_vector_save_bench(int n)
     const char       * filename = "cpl_vector_save_bench.fits";
     const double       vval[] = {0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0};
     const int          nvals = (int)(sizeof(vval)/sizeof(double));
-    const cpl_vector * vec = cpl_vector_wrap(nvals, (double*)vval);
     cpl_propertylist * qclist = cpl_propertylist_new();
-    const size_t bytes = (size_t)n * cpl_test_get_bytes_vector(vec);
     char               key[81];
+    const cpl_vector * vec;
+    size_t bytes;
 
 
+    CPL_DIAG_PRAGMA_PUSH_IGN(-Wcast-qual);
+    vec = cpl_vector_wrap(nvals, (double*)vval);
+    CPL_DIAG_PRAGMA_POP;
+    bytes = (size_t)n * cpl_test_get_bytes_vector(vec);
+
     cpl_msg_info(cpl_func, "Benchmarking with %d %d-length vectors", n, nvals);
 
     for (i = 0; i < nprops; i++) {
@@ -1066,7 +1123,10 @@ static void cpl_vector_save_bench(int n)
     cpl_test_fits(filename);
     cpl_test_zero( remove(filename) );
 
+    CPL_DIAG_PRAGMA_PUSH_IGN(-Wcast-qual);
     cpl_vector_unwrap((cpl_vector*)vec);
+    CPL_DIAG_PRAGMA_POP;
+
     cpl_propertylist_delete(qclist);
 
     return;
@@ -1161,3 +1221,209 @@ static void cpl_vector_fit_gaussian_test_one(FILE * stream)
     cpl_matrix_delete(cov);
     
 }
+
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    Perform a number of benchmarks
+  @param a  One pre-allocated vector
+  @param b  A second pre-allocated vector of the same length
+  @return   void
+ */
+/*----------------------------------------------------------------------------*/
+static void cpl_vector_valarray_bench_one(cpl_vector * a, cpl_vector * b)
+{
+  const cpl_size n = cpl_vector_get_size(a);
+  double         cputime, tstop;
+  const double   tstart = cpl_test_get_cputime();
+
+  cpl_vector_add(a, b);
+  cpl_vector_subtract(a, b);
+  cpl_vector_multiply(a, b);
+  cpl_vector_divide(a, b);
+  cpl_vector_add_scalar(a, 10);
+  cpl_vector_subtract_scalar(a, 10);
+  cpl_vector_multiply_scalar(a, 10);
+  cpl_vector_divide_scalar(a, 10);
+  cpl_vector_get_min(a);
+  cpl_vector_get_max(a);
+  cpl_vector_get_sum(a);
+  cpl_vector_get_mean(a);
+  cpl_vector_get_stdev(a);
+
+  tstop = cpl_test_get_cputime();
+  cputime = tstop - tstart;
+
+  cpl_msg_info(cpl_func, "valarray-test. n=%u. CPU-time [ms]: %g",
+               (unsigned)n, 1e3 * cputime);
+
+}
+
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    Perform a number of benchmarks of a given length
+  @param n  The length of the vector(s) to benchmark
+  @return   void
+ */
+/*----------------------------------------------------------------------------*/
+static void cpl_vector_valarray_bench(cpl_size n)
+{
+
+    cpl_vector * a = cpl_vector_new(n);
+    cpl_vector * b = cpl_vector_new(n);
+
+    cpl_vector_fill(a, 10.0);
+    cpl_vector_fill(b, 15.0);
+
+    cpl_vector_valarray_bench_one(a, b);
+
+    cpl_vector_delete(a);
+    cpl_vector_delete(b);
+}
+
+
+
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    Test the CPL function
+  @param n  The length of the vector(s) to test
+  @return   void
+ */
+/*----------------------------------------------------------------------------*/
+static void cpl_vector_cycle_test(cpl_size n)
+{
+
+    const cpl_boolean do_plot = cpl_msg_get_level() <= CPL_MSG_INFO
+        ? CPL_TRUE : CPL_FALSE;
+    cpl_vector* src;
+    cpl_vector* dest;
+    cpl_error_code code;
+
+    src  = cpl_vector_new(n);
+    dest = cpl_vector_new(n + 1);
+
+    /* Shift something non-constant, so the correctness can be verified */
+    code = cpl_vector_fill_kernel_profile(src, CPL_KERNEL_SINC, 1.0);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    code = cpl_vector_cycle(NULL, NULL, 1.0);
+    cpl_test_eq_error(code, CPL_ERROR_NULL_INPUT);
+
+    code = cpl_vector_cycle(NULL, src, 1.0);
+    cpl_test_eq_error(code, CPL_ERROR_NULL_INPUT);
+
+    code = cpl_vector_cycle(dest, src, 1.0);
+    cpl_test_eq_error(code, CPL_ERROR_INCOMPATIBLE_INPUT);
+
+    cpl_vector_delete(dest);
+    dest = cpl_vector_new(n);
+
+    code = cpl_vector_cycle(dest, src, CPL_MATH_SQRT2 + (double)n/3.0);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    if (do_plot) {
+        code = cpl_plot_vector("", "w lines", "", dest);
+        cpl_test_error(code);
+    }
+
+    code = cpl_vector_cycle(dest, NULL, -CPL_MATH_SQRT2 - (double)n/3.0);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    if (cpl_tools_is_power_of_2(n)) {
+        cpl_test_vector_abs(dest, src, 0.5 / n);
+    } else {
+        cpl_test_vector_abs(dest, src, 10.0 * DBL_EPSILON);
+    }
+
+    if (do_plot) {
+        code = cpl_vector_subtract(dest, src);
+        cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+        code = cpl_plot_vector("", "w lines", "", dest);
+        cpl_test_error(code);
+    }
+
+    code = cpl_vector_cycle(dest, src, 0.0);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    cpl_test_vector_abs(dest, src, 0.0);
+
+    code = cpl_vector_cycle(dest, NULL, 0.0);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    cpl_test_vector_abs(dest, src, 0.0);
+
+    /* Should not alias input, but it is supported */
+    code = cpl_vector_cycle(dest, dest, 0.0);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    cpl_test_vector_abs(dest, src, 0.0);
+
+    code = cpl_vector_cycle(dest, src, -1.0);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    if (n > 1) {
+        cpl_test_abs(cpl_vector_get(dest, n-1), cpl_vector_get(src, 0), 0.0);
+        cpl_test_abs(cpl_vector_get(dest, 0), cpl_vector_get(src, 1), 0.0);
+    }
+
+    code = cpl_vector_cycle(dest, NULL, 1.0);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    cpl_test_vector_abs(dest, src, 0.0);
+
+    code = cpl_vector_cycle(dest, NULL, -2.0);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    if (n > 2) {
+        cpl_test_abs(cpl_vector_get(dest, n-2), cpl_vector_get(src, 0), 0.0);
+        cpl_test_abs(cpl_vector_get(dest, 0), cpl_vector_get(src, 2), 0.0);
+    }
+
+    code = cpl_vector_cycle(dest, NULL,  2.0);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    cpl_test_vector_abs(dest, src, 0.0);
+
+    /* Perform a range of shifts, that will cancel each other out */
+    for (cpl_size i = -1 - 2 * n; i <= 1 + 2 * n; i++) {
+        code = cpl_vector_cycle(dest, NULL, i);
+        cpl_test_eq_error(code, CPL_ERROR_NONE);
+    }
+    cpl_test_vector_abs(dest, src, 0.0);
+
+    /* Fill the vector with a sine curve
+       - any linear combination of full sine and cosine curves
+       will be cycled accurately... */
+
+    for (cpl_size i=0; i < n; i++) {
+        const double value = sin(i * CPL_MATH_2PI / n);
+        code = cpl_vector_set(src, i, value);
+        cpl_test_eq_error(code, CPL_ERROR_NONE);
+    }
+
+    code = cpl_vector_cycle(dest, src, CPL_MATH_E + (double)n/5.0);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    code = cpl_vector_cycle(dest, NULL, -CPL_MATH_E - (double)n/5.0);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    cpl_test_vector_abs(dest, src, 20.0 * DBL_EPSILON);
+
+    /* Vectors of length 1 */
+
+    code = cpl_vector_set_size(src, 1);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    code = cpl_vector_set_size(dest, 1);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    code = cpl_vector_cycle(dest, src, 0.0);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    cpl_test_vector_abs(dest, src, 0.0);
+
+    code = cpl_vector_cycle(dest, src, 1.0);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    cpl_test_vector_abs(dest, src, 0.0);
+
+    code = cpl_vector_cycle(dest, src, -1.0);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    cpl_test_vector_abs(dest, src, 0.0);
+
+    cpl_vector_delete(src);
+    cpl_vector_delete(dest);
+
+}
