@@ -1,7 +1,6 @@
-/* $Id: cpl_dfs.c,v 1.138 2013-10-21 07:57:46 llundin Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2008 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: llundin $
- * $Date: 2013-10-21 07:57:46 $
- * $Revision: 1.138 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -535,7 +527,7 @@ cpl_error_code cpl_dfs_save_paf(const char * instrume, const char *recipe,
  *       set. Finally, if the keyword DPR.CATG is found in the header of 
  *       the first frame and is set to "SCIENCE", the boolean keyword 
  *       PRO.SCIENCE will be set to "true", otherwise it will be copied
- *       from an existing PRO.SCIENCE jeyword, while it will be set to 
+ *       from an existing PRO.SCIENCE keyword, while it will be set to 
  *       "false" in all other cases.
  *
  *    -# Check the existence of the keyword PRO.DATANCOM in @em header. If
@@ -1995,9 +1987,10 @@ static char * cpl_dfs_find_md5sum(fitsfile * fproduct)
 /*----------------------------------------------------------------------------*/
 static int cpl_is_fits(const char * self)
 {
-    int          error = 0;
-    int          is_fits = 1;
-    fitsfile   * fptr;
+    cpl_errorstate prestate = cpl_errorstate_get();
+    int            error = 0;
+    int            is_fits = 1;
+    fitsfile     * fptr;
 
 
     cpl_ensure(self != NULL, CPL_ERROR_NULL_INPUT, -1);
@@ -2005,9 +1998,12 @@ static int cpl_is_fits(const char * self)
     if (cpl_io_fits_open_diskfile(&fptr, self, READONLY, &error)) {
         is_fits = error == FILE_NOT_OPENED ? -2 : 0;
 
-        if (is_fits < 0)
-            (void)cpl_error_set_fits(CPL_ERROR_FILE_NOT_FOUND, error,
-                                     fits_open_diskfile, "filename='%s'", self);
+        if (is_fits < 0) {
+            (void)cpl_error_set_message_(CPL_ERROR_FILE_NOT_FOUND,
+                                         "filename='%s'", self);
+        } else {
+            cpl_errorstate_set(prestate);
+        }
         error = 0;
 #ifndef CPL_IO_FITS_REWIND
     } else if (fits_movabs_hdu(fptr, 1, NULL, &error)) {
@@ -2502,7 +2498,8 @@ static cpl_error_code cpl_dfs_product_save(cpl_frameset            * allframes,
 
     product_frame = cpl_frame_new();
 
-    /* Create product frame */
+    /* Create product frame.
+       NB: With multiple errors, error will differ from the actual CPL error */
     error |= cpl_frame_set_filename(product_frame, filename);
     error |= cpl_frame_set_tag(product_frame, procat);
     error |= cpl_frame_set_type(product_frame, protype[pronum]);
@@ -2566,9 +2563,7 @@ static cpl_error_code cpl_dfs_product_save(cpl_frameset            * allframes,
 
     if (plist != header) cpl_propertylist_delete(plist);
 
-    cpl_ensure_code(!error, error);
-
-    return CPL_ERROR_NONE;
+    return error ? cpl_error_set_where_() : CPL_ERROR_NONE;
 
 }    
 
