@@ -1,7 +1,6 @@
-/* $Id: cpl_apertures.c,v 1.34 2012-11-14 12:23:29 llundin Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2008 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: llundin $
- * $Date: 2012-11-14 12:23:29 $
- * $Revision: 1.34 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -300,6 +292,7 @@ cpl_apertures * cpl_apertures_new_from_image(const cpl_image * self,
 
     if (dimage == NULL) {
         cpl_image_delete(labcopy);
+        cpl_image_delete(cimage);
         (void)cpl_error_set_where_();
         return NULL;
     }
