@@ -1,7 +1,6 @@
-/* $Id: cpl_detector.c,v 1.33 2012-10-29 14:27:53 llundin Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2008 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: llundin $
- * $Date: 2012-10-29 14:27:53 $
- * $Revision: 1.33 $
- * $Name: not supported by cvs2svn $
- */
-
 /*-----------------------------------------------------------------------------
                                    Includes
  -----------------------------------------------------------------------------*/
@@ -529,6 +521,7 @@ cpl_error_code cpl_detector_interpolate_rejected(cpl_image * self)
   @param    np      Number of points to generate.
   @param    homog   Homogeneity factor.
   @return   Newly allocated cpl_bivector object or NULL in error case
+  @note No NULL-pointer check in this internal function
 
   The returned object must be deallocated using cpl_bivector_delete().
 
@@ -559,7 +552,6 @@ cpl_error_code cpl_detector_interpolate_rejected(cpl_image * self)
   region at each point.
 
   Possible #_cpl_error_code_ set in this function:
-  - CPL_ERROR_NULL_INPUT if (one of) the input pointer(s) is NULL
   - CPL_ERROR_ILLEGAL_INPUT if np is not strictly positive
  */
 /*----------------------------------------------------------------------------*/
@@ -581,7 +573,6 @@ static cpl_bivector * cpl_bivector_gen_rect_poisson(const cpl_size * r,
     double          *   py;
 
     /* error handling: test arguments are correct */
-    cpl_ensure(r, CPL_ERROR_NULL_INPUT, NULL);
     cpl_ensure( np > 0, CPL_ERROR_ILLEGAL_INPUT, NULL);
 
     list = cpl_bivector_new(np);
@@ -691,11 +682,11 @@ static cpl_bivector * cpl_bivector_gen_rect_poisson(const cpl_size * r,
   @return   Newly allocated cpl_bivector object or NULL in error case
   @see      cpl_bivector_gen_rect_poisson
   @note The points are in polar coordinates with radians.
+  @note No NULL-pointer check in this internal function
 
   The returned object must be deallocated using cpl_bivector_delete().
 
   Possible #_cpl_error_code_ set in this function:
-  - CPL_ERROR_NULL_INPUT if (one of) the input pointer(s) is NULL
   - CPL_ERROR_ILLEGAL_INPUT if np is not strictly positive
  */
 /*----------------------------------------------------------------------------*/
@@ -718,7 +709,6 @@ static cpl_bivector * cpl_bivector_gen_ring_poisson(
     double          *   py = cpl_bivector_get_y_data(list);
 
     /* Check entries */
-    cpl_ensure(r    != NULL, CPL_ERROR_NULL_INPUT,    NULL);
     cpl_ensure(list != NULL, CPL_ERROR_ILLEGAL_INPUT, NULL);
 
     r1 = (cpl_size)r[2];
