@@ -1,7 +1,6 @@
-/* $Id: cpl_fit.c,v 1.46 2012-06-15 14:26:56 llundin Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2008 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: llundin $
- * $Date: 2012-06-15 14:26:56 $
- * $Revision: 1.46 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -528,7 +520,6 @@ cpl_fit_imagelist_polynomial_window_(cpl_imagelist       * self,
 
     const cpl_size    nc = cpl_imagelist_get_size(self);
     const cpl_size    np = cpl_vector_get_size(x_pos);
-    const cpl_image * first = cpl_imagelist_get_const(values, 0);
     cpl_matrix      * mv;   /* The transpose of the Vandermonde matrix, V' */
     cpl_matrix      * mh;   /* Upper triangular part of SPD Hankel matrix,
                             H = V' * V */
@@ -536,6 +527,7 @@ cpl_fit_imagelist_polynomial_window_(cpl_imagelist       * self,
     const cpl_vector * xhat;
     cpl_vector       * xtmp = NULL;
     const double     * dx;
+    double           * dmv;
     double            xmean;
     cpl_error_code    error;
     int i, j, k;
@@ -552,16 +544,16 @@ cpl_fit_imagelist_polynomial_window_(cpl_imagelist       * self,
     dx = cpl_vector_get_data_const(xhat);
 
     /* Create matrices */
-    mv = cpl_matrix_wrap(nc, np,
-                         cpl_malloc((size_t)nc * (size_t)np * sizeof(double)));
+    dmv = (double*)cpl_malloc((size_t)nc * (size_t)np * sizeof(*dmv));
+    mv  = cpl_matrix_wrap(nc, np, dmv);
 
     /* Fill Vandermonde matrix */
     for (j=0; j < np; j++) {
         double f_prod = cpl_tools_ipow(dx[j], (int)mindeg);
-        cpl_matrix_set(mv,  0, j, f_prod);
+        dmv[j] = f_prod;
         for (k=1; k < nc; k++) {
             f_prod *= dx[j];
-            cpl_matrix_set(mv, k, j, f_prod);
+            dmv[np * k + j] = f_prod;
         }
     }
 
@@ -600,6 +592,7 @@ cpl_fit_imagelist_polynomial_window_(cpl_imagelist       * self,
     error = cpl_matrix_decomp_chol(mh);
 
     if (!error) {
+        const cpl_image * first = cpl_imagelist_get_const(values, 0);
 
         const cpl_vector * xpow = NULL;
         xtmp = NULL;
