@@ -1,7 +1,6 @@
-/* $Id: cpl_geom_img.c,v 1.50 2012-04-04 12:26:54 llundin Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2008 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: llundin $
- * $Date: 2012-04-04 12:26:54 $
- * $Revision: 1.50 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -518,7 +510,8 @@ cpl_image ** cpl_geom_img_offset_combine(const cpl_imagelist* self,
   @param    kernel      Interpolation kernel to use for resampling
   @param    rejmin      Number of minimum value pixels to reject in stacking
   @param    rejmax      Number of maximum value pixels to reject in stacking
-  @param    union_flag  Combination mode (CPL_GEOM_UNION or CPL_GEOM_INTERSECT)
+  @param    union_flag  Combination mode, CPL_GEOM_UNION, CPL_GEOM_INTERSECT or
+                        CPL_GEOM_FIRST
   @param    ppos_x      If non-NULL, *ppos_x is the X-position of the first
                         image in the combined image
   @param    ppos_y      If non-NULL, *ppos_y is the Y- position of the first
@@ -527,7 +520,7 @@ cpl_image ** cpl_geom_img_offset_combine(const cpl_imagelist* self,
 
   The supported types are CPL_TYPE_DOUBLE, CPL_TYPE_FLOAT.
  
-  The number of provided offsets shall be equal to the number of inputs images.
+  The number of provided offsets shall be equal to the number of input images.
   The ith offset (offs_x, offs_y) is the offset that has to be used to shift 
   the ith image to align it on the first one.
   
