@@ -1,7 +1,6 @@
-/* $Id: cpl_wcs.c,v 1.55 2013-04-26 13:44:02 llundin Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2008 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: llundin $
- * $Date: 2013-04-26 13:44:02 $
- * $Revision: 1.55 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -320,9 +312,11 @@ cpl_wcs *cpl_wcs_new_from_propertylist(const cpl_propertylist *plist) {
 
             /* This is an image, see if it's a compressed image */
             const int compressed = cpl_propertylist_has(plist, "ZNAXIS");
-            const char * fmt = compressed ? "ZNAXIS%d" : "NAXIS%d";
             int i = wcs->naxis;
-            char * nax = cpl_sprintf(fmt, i); /* Sufficient, minimal length */
+            /* Sufficient, minimal length */
+            char * nax = compressed
+                ? cpl_sprintf("ZNAXIS%d", i)
+                : cpl_sprintf("NAXIS%d", i);
             char * naxd = nax + (compressed ? 6 : 5); /* Digit(s) start here */
 
             /* Now copy the stuff over to someplace where we can get it */
