@@ -1,7 +1,6 @@
-/* $Id: cpl_gasgano.c,v 1.23 2013-01-30 15:59:18 rpalsa Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2006 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: rpalsa $
- * $Date: 2013-01-30 15:59:18 $
- * $Revision: 1.23 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -1285,7 +1277,7 @@ static void err_message_handler(const cxchar *msg) {
 static void default_log_message_handler(const cxchar *domain,
                                         cx_log_level_flags flags,
                                         const cxchar *msg, cxptr ptr) {
-   JNIEnv *env;
+   JNIEnv *env = currentEnv;
    jstring jDomain;
    jstring jMsg;
    int ok = 1;
@@ -1295,8 +1287,7 @@ static void default_log_message_handler(const cxchar *domain,
    ok = omp_get_thread_num() == 0;
 #endif
 
-   ok = ok &&
-      (env = currentEnv);
+   ok = ok && env;
    jMsg = NULL;
    if (msg) {
       ok = ok &&
