@@ -1,7 +1,6 @@
-/* $Id: cpl_framedata.c,v 1.4 2012-01-11 13:38:29 rpalsa Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2006 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: rpalsa $
- * $Date: 2012-01-11 13:38:29 $
- * $Revision: 1.4 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -34,6 +26,7 @@
 #include <cxstrutils.h>
 
 #include "cpl_framedata.h"
+#include "cpl_error_impl.h"
 
 
 /**
@@ -156,12 +149,11 @@ cpl_framedata*
 cpl_framedata_duplicate(const cpl_framedata* other)
 {
 
-    static const cxchar* const _id = "cpl_framedata_duplicate";
 
     cpl_framedata* self = NULL;
 
     if (other == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
     }
     else {
 
@@ -269,11 +261,10 @@ const char*
 cpl_framedata_get_tag(const cpl_framedata* self)
 {
 
-    static const cxchar* const _id = "cpl_framedata_get_tag";
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return NULL;
     }
 
@@ -313,11 +304,10 @@ cpl_size
 cpl_framedata_get_min_count(const cpl_framedata* self)
 {
 
-    static const cxchar* const _id = "cpl_framedata_get_min_count";
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return -2;
     }
 
@@ -357,11 +347,10 @@ cpl_size
 cpl_framedata_get_max_count(const cpl_framedata* self)
 {
 
-    static const cxchar* const _id = "cpl_framedata_get_max_count";
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return -2;
     }
 
@@ -408,17 +397,14 @@ cpl_error_code
 cpl_framedata_set_tag(cpl_framedata* self, const char* tag)
 {
 
-    static const cxchar* const _id = "cpl_framedata_set_tag";
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
-        return CPL_ERROR_NULL_INPUT;
+        return cpl_error_set_(CPL_ERROR_NULL_INPUT);
     }
 
     if ((tag == NULL) || (tag[0] == '\0')) {
-        cpl_error_set(_id, CPL_ERROR_ILLEGAL_INPUT);
-        return CPL_ERROR_ILLEGAL_INPUT;
+        return cpl_error_set_(CPL_ERROR_ILLEGAL_INPUT);
     }
 
     if (self->tag != NULL) {
@@ -462,12 +448,10 @@ cpl_error_code
 cpl_framedata_set_min_count(cpl_framedata* self, cpl_size min_count)
 {
 
-    static const cxchar* const _id = "cpl_framedata_set_min_count";
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
-        return CPL_ERROR_NULL_INPUT;
+        return cpl_error_set_(CPL_ERROR_NULL_INPUT);
     }
 
     self->min_count = (min_count < -1) ? -1 : min_count;
@@ -508,12 +492,10 @@ cpl_error_code
 cpl_framedata_set_max_count(cpl_framedata* self, cpl_size max_count)
 {
 
-    static const cxchar* const _id = "cpl_framedata_set_max_count";
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
-        return CPL_ERROR_NULL_INPUT;
+        return cpl_error_set_(CPL_ERROR_NULL_INPUT);
     }
 
     self->max_count = (max_count < -1) ? -1 : max_count;
@@ -567,17 +549,14 @@ cpl_framedata_set(cpl_framedata* self, const char* tag, cpl_size min_count,
                   cpl_size max_count)
 {
 
-    static const cxchar* const _id = "cpl_framedata_set";
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
-        return CPL_ERROR_NULL_INPUT;
+        return cpl_error_set_(CPL_ERROR_NULL_INPUT);
     }
 
     if ((tag == NULL) || (tag[0] == '\0')) {
-        cpl_error_set(_id, CPL_ERROR_ILLEGAL_INPUT);
-        return CPL_ERROR_ILLEGAL_INPUT;
+        return cpl_error_set_(CPL_ERROR_ILLEGAL_INPUT);
     }
 
     if (self->tag != NULL) {
