@@ -1,7 +1,6 @@
-/* $Id: cpl_frameset.c,v 1.45 2013-08-28 06:44:37 rpalsa Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2005 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: rpalsa $
- * $Date: 2013-08-28 06:44:37 $
- * $Revision: 1.45 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -493,7 +485,6 @@ cpl_frameset *
 cpl_frameset_duplicate(const cpl_frameset *other)
 {
 
-    const cxchar *const _id = "cpl_frameset_duplicate";
 
     cx_list_iterator first, last;
 
@@ -501,7 +492,7 @@ cpl_frameset_duplicate(const cpl_frameset *other)
 
 
     if (other == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return NULL;
     }
 
@@ -588,11 +579,10 @@ cpl_size
 cpl_frameset_get_size(const cpl_frameset *self)
 {
 
-    const cxchar *const _id = "cpl_frameset_get_size";
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return 0;
     }
 
@@ -629,11 +619,10 @@ int
 cpl_frameset_is_empty(const cpl_frameset *self)
 {
 
-    const cxchar *const _id = "cpl_frameset_is_empty";
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return 0;
     }
 
@@ -673,11 +662,10 @@ int
 cpl_frameset_count_tags(const cpl_frameset *self, const char *tag)
 {
 
-    const cxchar *const _id = "cpl_frameset_count_tags";
 
 
     if (self == NULL || tag == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return 0;
     }
 
@@ -729,7 +717,6 @@ const cpl_frame *
 cpl_frameset_find_const(const cpl_frameset *self, const char *tag)
 {
 
-    const cxchar *const _id = "cpl_frameset_find_const";
 
     cx_multimap_iterator pos;
     cx_multimap_iterator cached;
@@ -739,7 +726,7 @@ cpl_frameset_find_const(const cpl_frameset *self, const char *tag)
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return NULL;
     }
 
@@ -885,10 +872,9 @@ const cpl_frame *
 cpl_frameset_get_first_const(const cpl_frameset *self)
 {
 
-    const cxchar *const _id = "cpl_frameset_get_first_const";
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return NULL;
     }
 
@@ -933,10 +919,9 @@ cpl_frame *
 cpl_frameset_get_first(cpl_frameset *self)
 {
 
-    const cxchar *const _id = "cpl_frameset_get_first";
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return NULL;
     }
 
@@ -985,11 +970,10 @@ const cpl_frame *
 cpl_frameset_get_next_const(const cpl_frameset *self)
 {
 
-    const cxchar *const _id = "cpl_frameset_get_next_const";
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return NULL;
     }
 
@@ -1039,10 +1023,9 @@ cpl_frame *
 cpl_frameset_get_next(cpl_frameset *self)
 {
 
-    const cxchar *const _id = "cpl_frameset_get_next";
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return NULL;
     }
 
@@ -1097,7 +1080,6 @@ cpl_error_code
 cpl_frameset_insert(cpl_frameset *self, cpl_frame *frame)
 {
 
-    const cxchar *const _id = "cpl_frameset_insert";
 
 
     const cxchar *tag = NULL;
@@ -1106,15 +1088,13 @@ cpl_frameset_insert(cpl_frameset *self, cpl_frame *frame)
 
 
     if (self == NULL || frame == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
-        return CPL_ERROR_NULL_INPUT;
+        return cpl_error_set_(CPL_ERROR_NULL_INPUT);
     }
 
     tag = cpl_frame_get_tag(frame);
 
     if (tag == NULL) {
-        cpl_error_set(_id, CPL_ERROR_ILLEGAL_INPUT);
-        return CPL_ERROR_ILLEGAL_INPUT;
+        return cpl_error_set_(CPL_ERROR_ILLEGAL_INPUT);
     }
 
     position = cx_multimap_insert(self->frames, tag, frame);
@@ -1159,7 +1139,6 @@ cpl_size
 cpl_frameset_erase(cpl_frameset *self, const char *tag)
 {
 
-    const cxchar *const _id = "cpl_frameset_erase";
 
     cxsize count = 0;
 
@@ -1169,7 +1148,7 @@ cpl_frameset_erase(cpl_frameset *self, const char *tag)
 
 
     if (self == NULL || tag == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return count;
     }
 
@@ -1262,14 +1241,12 @@ cpl_error_code
 cpl_frameset_erase_frame(cpl_frameset *self, cpl_frame *frame)
 {
 
-    const cxchar *const _id = "cpl_frameset_erase_frame";
 
     cx_multimap_iterator first, last;
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
-        return CPL_ERROR_NULL_INPUT;
+        return cpl_error_set_(CPL_ERROR_NULL_INPUT);
     }
 
     if (!frame) {
@@ -1362,12 +1339,10 @@ cpl_error_code
 cpl_frameset_join(cpl_frameset *self, const cpl_frameset *other)
 {
 
-    const cxchar *const _id = "cpl_frameset_join";
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
-        return CPL_ERROR_NULL_INPUT;
+        return cpl_error_set_(CPL_ERROR_NULL_INPUT);
     }
 
     if ((other != NULL) && (cpl_frameset_is_empty(other) != 1)) {
@@ -1392,7 +1367,7 @@ cpl_frameset_join(cpl_frameset *self, const cpl_frameset *other)
 
             if (status != CPL_ERROR_NONE) {
                 cpl_frame_delete(frame);
-                cpl_error_set(_id, status);
+                cpl_error_set_(status);
 
                 return status;
             }
@@ -1450,12 +1425,10 @@ cpl_error_code
 cpl_frameset_sort(cpl_frameset *self, cpl_frame_compare_func compare)
 {
 
-    const cxchar *const _id = "cpl_frameset_sort";
 
 
     if ((self == NULL) || (compare == NULL)) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
-        return CPL_ERROR_NULL_INPUT;
+        return cpl_error_set_(CPL_ERROR_NULL_INPUT);
     }
 
     return _cpl_frameset_history_sort(self->history, self->frames, compare);
@@ -1673,15 +1646,14 @@ const cpl_frame *
 cpl_frameset_get_frame_const(const cpl_frameset *set, cpl_size position)
 {
 
-    const cxchar *const _id = "cpl_frameset_get_frame_const";
 
     if (set == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return NULL;
     }
 
     if ((position < 0) || (position >= cpl_frameset_get_size(set))) {
-        cpl_error_set(_id, CPL_ERROR_ILLEGAL_INPUT);
+        cpl_error_set_(CPL_ERROR_ILLEGAL_INPUT);
         return NULL;
     }
 
@@ -1744,15 +1716,14 @@ cpl_frame *
 cpl_frameset_get_frame(cpl_frameset *set, cpl_size position)
 {
 
-    const cxchar *const _id = "cpl_frameset_get_frame";
 
     if (set == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return NULL;
     }
 
     if ((position < 0) || (position >= cpl_frameset_get_size(set))) {
-        cpl_error_set(_id, CPL_ERROR_ILLEGAL_INPUT);
+        cpl_error_set_(CPL_ERROR_ILLEGAL_INPUT);
         return NULL;
     }
 
@@ -1799,7 +1770,6 @@ cpl_frame *
 cpl_frameset_get_position(cpl_frameset *self, cpl_size position)
 {
 
-    const cxchar *const _id = "cpl_frameset_get_position";
 
     cx_list_iterator _position = NULL;
 
@@ -1807,12 +1777,12 @@ cpl_frameset_get_position(cpl_frameset *self, cpl_size position)
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return NULL;
     }
 
     if ((position < 0) || (position >= cpl_frameset_get_size(self))) {
-        cpl_error_set(_id, CPL_ERROR_ILLEGAL_INPUT);
+        cpl_error_set_(CPL_ERROR_ILLEGAL_INPUT);
         return NULL;
     }
 
@@ -1872,7 +1842,6 @@ const cpl_frame *
 cpl_frameset_get_position_const(const cpl_frameset *self, cpl_size position)
 {
 
-    const cxchar *const _id = "cpl_frameset_get_position_const";
 
     cx_list_iterator _position = NULL;
 
@@ -1880,12 +1849,12 @@ cpl_frameset_get_position_const(const cpl_frameset *self, cpl_size position)
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return NULL;
     }
 
     if ((position < 0) || (position >= cpl_frameset_get_size(self))) {
-        cpl_error_set(_id, CPL_ERROR_ILLEGAL_INPUT);
+        cpl_error_set_(CPL_ERROR_ILLEGAL_INPUT);
         return NULL;
     }
 
@@ -2122,13 +2091,12 @@ cpl_frameset_iterator *
 cpl_frameset_iterator_new(const cpl_frameset *parent)
 {
 
-    const cxchar *const _id = "cpl_frameset_iterator_new";
 
     cpl_frameset_iterator *self = NULL;
 
 
     if (parent == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return NULL;
     }
 
@@ -2175,13 +2143,12 @@ cpl_frameset_iterator *
 cpl_frameset_iterator_duplicate(const cpl_frameset_iterator *other)
 {
 
-    const cxchar *const _id = "cpl_frameset_iterator_duplicate";
 
     cpl_frameset_iterator *self = NULL;
 
 
     if (other == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return NULL;
     }
 
@@ -2257,17 +2224,14 @@ cpl_frameset_iterator_assign(cpl_frameset_iterator *self,
                              const cpl_frameset_iterator *other)
 {
 
-    const cxchar *const _id = "cpl_frameset_iterator_assign";
 
 
     if ((self == NULL) || (other == NULL)) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
-        return CPL_ERROR_NULL_INPUT;
+        return cpl_error_set_(CPL_ERROR_NULL_INPUT);
     }
 
     if (self->parent != other->parent) {
-        cpl_error_set(_id, CPL_ERROR_ILLEGAL_INPUT);
-        return CPL_ERROR_ILLEGAL_INPUT;
+        return cpl_error_set_(CPL_ERROR_ILLEGAL_INPUT);
     }
 
 
@@ -2353,11 +2317,9 @@ cpl_error_code
 cpl_frameset_iterator_advance(cpl_frameset_iterator *self, int distance)
 {
 
-    const cxchar *const _id = "cpl_frameset_iterator_advance";
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
-        return CPL_ERROR_NULL_INPUT;
+        return cpl_error_set_(CPL_ERROR_NULL_INPUT);
     }
     else {
 
@@ -2397,8 +2359,7 @@ cpl_frameset_iterator_advance(cpl_frameset_iterator *self, int distance)
 
         if (_distance != 0) {
 
-            cpl_error_set(_id, CPL_ERROR_ACCESS_OUT_OF_RANGE);
-            return CPL_ERROR_ACCESS_OUT_OF_RANGE;
+            return cpl_error_set_(CPL_ERROR_ACCESS_OUT_OF_RANGE);
 
         }
         else {
@@ -2469,18 +2430,17 @@ cpl_frameset_iterator_distance(const cpl_frameset_iterator *self,
                                const cpl_frameset_iterator *other)
 {
 
-    const cxchar *const _id = "cpl_frameset_iterator_distance";
 
     int invalid = 0;
 
 
     if ((self == NULL) || (other == NULL)) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return invalid;
     }
 
     if (self->parent != other->parent) {
-        cpl_error_set(_id, CPL_ERROR_ILLEGAL_INPUT);
+        cpl_error_set_(CPL_ERROR_ILLEGAL_INPUT);
         return invalid;
     }
 
@@ -2533,7 +2493,7 @@ cpl_frameset_iterator_distance(const cpl_frameset_iterator *self,
          * Nothing was found in any direction. This should not happen!
          */
 
-        cpl_error_set(_id, CPL_ERROR_DATA_NOT_FOUND);
+        cpl_error_set_(CPL_ERROR_DATA_NOT_FOUND);
         return invalid;
 
     }
@@ -2574,13 +2534,12 @@ cpl_frame *
 cpl_frameset_iterator_get(cpl_frameset_iterator *self)
 {
 
-    const cxchar *const _id = "cpl_frameset_iterator_get";
 
     cx_multimap_iterator position = NULL;
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return NULL;
     }
 
@@ -2603,8 +2562,10 @@ cpl_frameset_iterator_get(cpl_frameset_iterator *self)
  * @param self  The frame set iterator to dereference.
  *
  * @return
- *   The frame stored in the frame set at the position of the iterator, or
- *   @c NULL if an error occurs.
+ *   The frame stored in the frame set at the position of the iterator or
+ *   @c NULL if an error occurs. The function also returns @c NULL if the
+ *   iterator is positioned at the sentinel element (i.e. the
+ *   one-before-the-beginning or one-past-the-end position).
  *
  * @error
  *   <table class="ec" align="center">
@@ -2617,21 +2578,20 @@ cpl_frameset_iterator_get(cpl_frameset_iterator *self)
  *   </table>
  * @enderror
  *
- * The function dereferences the iterator @em self, i.e. it retrieves the frame
- * at the position pointed to by @em self.
+ * The function dereferences the iterator @em self, i.e. it retrieves the
+ * frame at the position pointed to by @em self.
  */
 
 const cpl_frame *
 cpl_frameset_iterator_get_const(const cpl_frameset_iterator *self)
 {
 
-    const cxchar *const _id = "cpl_frameset_iterator_get_const";
 
     cx_multimap_iterator position = NULL;
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return NULL;
     }
 
