@@ -1,7 +1,6 @@
-/* $Id: cpl_parameterlist.c,v 1.16 2012-12-13 13:54:18 rpalsa Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2005 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: rpalsa $
- * $Date: 2012-12-13 13:54:18 $
- * $Revision: 1.16 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -40,7 +32,7 @@
 #include "cpl_parameterlist.h"
 
 #include "cpl_errorstate.h"
-
+#include "cpl_error_impl.h"
 
 /**
  * @defgroup cpl_parameterlist Parameter Lists
@@ -156,11 +148,10 @@ cpl_size
 cpl_parameterlist_get_size(const cpl_parameterlist *self)
 {
 
-    const cxchar *const _id = "cpl_parameterlist_get_size";
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return 0;
     }
 
@@ -198,12 +189,10 @@ cpl_error_code
 cpl_parameterlist_append(cpl_parameterlist *self, cpl_parameter *parameter)
 {
 
-    const cxchar *const _id = "cpl_parameterlist_append";
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
-        return CPL_ERROR_NULL_INPUT;
+        return cpl_error_set_(CPL_ERROR_NULL_INPUT);
     }
 
     cx_slist_push_back(self->data, parameter);
@@ -245,13 +234,12 @@ const cpl_parameter *
 cpl_parameterlist_get_first_const(const cpl_parameterlist *self)
 {
 
-    const cxchar *const _id = "cpl_parameterlist_get_first_const";
 
     cpl_parameterlist *_self = (cpl_parameterlist *)self;
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return NULL;
     }
 
@@ -342,7 +330,6 @@ const cpl_parameter *
 cpl_parameterlist_get_next_const(const cpl_parameterlist *self)
 {
 
-    const cxchar *const _id = "cpl_parameterlist_get_next_const";
 
     cx_slist_iterator next;
 
@@ -350,7 +337,7 @@ cpl_parameterlist_get_next_const(const cpl_parameterlist *self)
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return NULL;
     }
 
@@ -447,16 +434,15 @@ const cpl_parameter *
 cpl_parameterlist_get_last_const(const cpl_parameterlist *self)
 {
 
-    const cxchar *const _id = "cpl_parameterlist_get_last_const";
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return NULL;
     }
 
     if (cx_slist_empty(self->data)) {
-        cpl_error_set(_id, CPL_ERROR_ILLEGAL_INPUT);
+        cpl_error_set_(CPL_ERROR_ILLEGAL_INPUT);
         return NULL;
     }
 
@@ -543,13 +529,12 @@ const cpl_parameter *
 cpl_parameterlist_find_const(const cpl_parameterlist *self, const char *name)
 {
 
-    const cxchar *const _id = "cpl_parameterlist_find_const";
 
     cx_slist_iterator first, last;
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return NULL;
     }
 
@@ -650,13 +635,12 @@ const cpl_parameter *
 cpl_parameterlist_find_type_const(const cpl_parameterlist *self, cpl_type type)
 {
 
-    const cxchar *const _id = "cpl_parameterlist_find_type_const";
 
     cx_slist_iterator first, last;
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return NULL;
     }
 
@@ -758,13 +742,12 @@ cpl_parameterlist_find_context_const(const cpl_parameterlist *self,
                                const char *context)
 {
 
-    const cxchar *const _id = "cpl_parameterlist_find_context_const";
 
     cx_slist_iterator first, last;
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return NULL;
     }
 
@@ -882,13 +865,12 @@ cpl_parameterlist_find_context(cpl_parameterlist *self,
 const cpl_parameter *
 cpl_parameterlist_find_tag_const(const cpl_parameterlist *self, const char *tag)
 {
-    const cxchar *const _id = "cpl_parameterlist_find_tag_const";
 
     cx_slist_iterator first, last;
 
 
     if (self == NULL) {
-        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return NULL;
     }
 
