@@ -1,7 +1,6 @@
-/* $Id: cpl_plugin.c,v 1.17 2011-01-11 10:32:48 llundin Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2005 European Southern Observatory
+ * Copyright (C) 2001-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: llundin $
- * $Date: 2011-01-11 10:32:48 $
- * $Revision: 1.17 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -1577,28 +1569,30 @@ cpl_plugin_dump(const cpl_plugin *self, FILE *stream)
             stream = stdout;
         }
 
-        fprintf(stream, "Plugin at %p:\n", self);
+        fprintf(stream, "Plugin at %p:\n", (const void*)self);
 
         s = cpl_plugin_get_name(self);
         fprintf(stream, "  Name (%p): %s\n", s, s);
 
         a = cpl_plugin_get_version_string(self);
-        fprintf(stream, "  Version: %s (%ld)\n", a,
+        fprintf(stream, "  Version: %s (%lu)\n", a,
                 cpl_plugin_get_version(self));
         cx_free(a);
 
         a = cpl_plugin_get_type_string(self);
-        fprintf(stream, "  Type: %s (%ld)\n", a, cpl_plugin_get_type(self));
+        fprintf(stream, "  Type: %s (%lu)\n", a, cpl_plugin_get_type(self));
         cx_free(a);
 
-        fprintf(stream, "  API Version: %d", cpl_plugin_get_api(self));
+        fprintf(stream, "  API Version: %u", cpl_plugin_get_api(self));
 
+CPL_DIAG_PRAGMA_PUSH_IGN(-Wformat=);
         fprintf(stream, "  Initialization handler at %p\n",
                 cpl_plugin_get_init(self));
         fprintf(stream, "  Execution handler at %p\n",
                 cpl_plugin_get_exec(self));
         fprintf(stream, "  Cleanup handler at %p\n",
                 cpl_plugin_get_deinit(self));
+CPL_DIAG_PRAGMA_POP;
 
         s = cpl_plugin_get_synopsis(self);
         fprintf(stream, "  Synopsis (%p): %s\n", s, s);
